@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-client.c,v 1.5 1999/09/24 06:38:52 wiegand Exp $
+ * $Id: ftp-client.c,v 1.6 1999/10/19 11:04:51 wiegand Exp $
  *
  * Functions for the FTP Proxy client handling
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-client.c,v 1.5 1999/09/24 06:38:52 wiegand Exp $";
+static char rcsid[] = "$Id: ftp-client.c,v 1.6 1999/10/19 11:04:51 wiegand Exp $";
 #endif
 
 #include <config.h>
@@ -128,11 +128,10 @@ static RETSIGTYPE client_signal(int signo)
 
 void client_run(void)
 {
-	int sock, need;
+	int sock, need, diff;
 	char str[1024], *p, *q;
 	FILE *fp;
 	BUF *buf;
-	time_t diff;
 
 	/*
 	** Setup client signal handling (mostly graceful exit)
@@ -296,12 +295,15 @@ void client_run(void)
 			/*
 			** Good time for statistics and data reset
 			*/
-			if ((diff = time(NULL) - ctx.xfer_beg) < 1)
+			if (ctx.xfer_beg == 0)
+				ctx.xfer_beg = time(NULL);
+			diff = (int) (time(NULL) - ctx.xfer_beg);
+			if (diff < 1)
 				diff = 1;
 			syslog_write(U_INF,
 				"Transfer for %s: %s '%s' %d sec",
 				ctx.cli_ctrl->peer, ctx.xfer_cmd,
-				ctx.xfer_arg, (int) diff);
+				ctx.xfer_arg, diff);
 			client_data_reset();
 
 			/*
@@ -949,6 +951,9 @@ void client_data_reset(void)
 
 /* ------------------------------------------------------------
  * $Log: ftp-client.c,v $
+ * Revision 1.6  1999/10/19 11:04:51  wiegand
+ * make sure transfer time has reasonable value
+ *
  * Revision 1.5  1999/09/24 06:38:52  wiegand
  * added regular expressions for all commands
  * removed character map and length of paths
