@@ -1,5 +1,5 @@
 /*
- * $Id: ftp-cmds.c,v 1.6 1999/09/30 09:48:36 wiegand Exp $
+ * $Id: ftp-cmds.c,v 1.7 1999/10/19 10:19:15 wiegand Exp $
  *
  * FTP Proxy command handling
  *
@@ -30,7 +30,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "$Id: ftp-cmds.c,v 1.6 1999/09/30 09:48:36 wiegand Exp $";
+static char rcsid[] = "$Id: ftp-cmds.c,v 1.7 1999/10/19 10:19:15 wiegand Exp $";
 #endif
 
 #include <config.h>
@@ -344,6 +344,7 @@ static void cmds_user(CONTEXT *ctx, char *arg)
 	CMD *cmd;
 	int sock;
 	struct sockaddr_in saddr;
+	u_int16_t lprt;
 
 	if (ctx == NULL)		/* Basic sanity check	*/
 		misc_die(FL, "cmds_user: ?ctx?");
@@ -436,14 +437,46 @@ static void cmds_user(CONTEXT *ctx, char *arg)
 	}
 	socket_opts(sock, SK_CONTROL);
 
+	/*
+	** Bind the socket, taking care of a given port range
+	*/
+	if (ctx->srv_lrng > 0 && ctx->srv_urng > 0) {
+		memset(&saddr, 0, sizeof(saddr));
+		saddr.sin_addr.s_addr = INADDR_ANY;
+		saddr.sin_family      = AF_INET;
+
+		for (lprt = ctx->srv_lrng;
+				lprt <= ctx->srv_urng; lprt++) {
+#if defined(COMPILE_DEBUG)
+			debug(2, "try to con-bind Srv-Ctrl to 0:%d",
+							(int) lprt);
+#endif
+			saddr.sin_port = htons(lprt);
+			if (bind(sock, (struct sockaddr *) &saddr,
+						sizeof(saddr)) == 0)
+				break;
+			if (errno != EADDRINUSE)
+				lprt = ctx->srv_urng + 1;
+		}
+		if (lprt > ctx->srv_urng) {	/* nothing found? */
+			close(sock);
+			syslog_error("can't bind Srv-Ctrl "
+					"to 0:%d-%d for %s",
+					(int) ctx->srv_lrng,
+					(int) ctx->srv_urng,
+					ctx->cli_ctrl->peer);
+			exit(EXIT_FAILURE);
+		}
+	}
+
+	/*
+	** Okay, now try the actual connect to the server
+	*/
 	memset(&saddr, 0, sizeof(saddr));
 	saddr.sin_addr.s_addr = htonl(ctx->srv_addr);
 	saddr.sin_family      = AF_INET;
 	saddr.sin_port        = htons(ctx->srv_port);
 
-	/*
-	** Okay, now try the actual connect to the server
-	*/
 	if (connect(sock, (struct sockaddr *) &saddr,
 					sizeof(saddr)) < 0) {
 		syslog_error("can't connect %s:%d for %s",
@@ -1124,6 +1157,9 @@ char *cmds_reg_exec(void *regex, char *str)
 
 /* ------------------------------------------------------------
  * $Log: ftp-cmds.c,v $
+ * Revision 1.7  1999/10/19 10:19:15  wiegand
+ * use port range also for control connection to server
+ *
  * Revision 1.6  1999/09/30 09:48:36  wiegand
  * added global RegEx check for USER command
  * added dynamic TranslatedAddress via file
